window.Gleam.initSearch([{"doc":"glisten","title":"glisten","content":"# glisten\n\nSee the docs [here](https://hexdocs.pm/glisten/).\n\nIt uses the `gleam_otp` library to handle the supervisor and child processes.\n\n`glisten` provides a supervisor which manages a pool of acceptors. Each acceptor\nwill block on `accept` until a connection is opened.  The acceptor will then\nspawn a handler process and then block again on `accept`.\n\nThe most obvious entrypoint is `glisten.{serve}` which listens for TCP\nconnections on a given port.  It also takes a handler function wrapper\n`handler.{func}` which you can provide functionality to, and the state which\neach TCP connection process will hold.  This takes the shape of:\n\n```gleam\ntype HandlerFunc(data) =\n  fn(BitString, LoopState(data)) -&gt; actor.Next(LoopState(data))\n```\n\nSSL is also handled using the `glisten.{serve_ssl}` method.  This requires a\ncertificate and key file path.  The rest of the handler flow remains unchanged.\n\n`glisten` doesn&#39;t provide a public API for connected clients.  In order to hook\ninto the socket lifecyle, you can establish some functions which are called\nfor the opening and closing of the socket.  An example is provided below.\n\n## Examples\n\nHere is a basic echo server:\n\n```gleam\nimport gleam/bit_builder\nimport gleam/erlang/process\nimport gleam/otp/actor\nimport gleam/result\nimport glisten/acceptor\nimport glisten/handler\nimport glisten/tcp\nimport glisten\n\npub fn main() {\n  handler.func(fn(msg, state) {\n    let assert Ok(_) = tcp.send(state.socket, bit_builder.from_bit_string(msg))\n    actor.Continue(state)\n  })\n  |&gt; acceptor.new_pool\n  |&gt; glisten.serve(8080, _)\n  |&gt; result.map(fn(_) { process.sleep_forever() })\n}\n```\n\nTo serve over SSL:\n\n```gleam\n// ...\nimport glisten/ssl\n\npub fn main() {\n  handler.func(fn(msg, state) {\n    let assert Ok(_) = ssl.send(state.socket, bit_builder.from_bit_string(msg))\n    actor.Continue(state)\n  })\n  |&gt; acceptor.new_pool\n  |&gt; glisten.serve_ssl(\n    // Passing labeled arguments for clarity\n    port: 8080,\n    certfile: &quot;/path/to/server.crt&quot;,\n    keyfile: &quot;/path/to/server.key&quot;,\n    with_pool: _,\n  )\n  |&gt; result.map(fn(_) { process.sleep_forever() })\n}\n```\n\nManaging connected clients can be handled similarly to this simple example.\nThe `with_init` callback will be called after the SSL handshake, if the\nunderlying socket is set up to use it.\n\n```gleam\nimport gleam/bit_builder\nimport gleam/erlang/process\nimport glisten/handler\nimport glisten/tcp\nimport glisten\n\npub fn main() {\n  // This function is omitted for brevity.  It simply manages a\n  // `gleam/set.{Set}` of `Sender(HandlerMessage)`s that &quot;broadcast&quot; the\n  // connect/disconnect events to all clients.\n  let assert Ok(connections) = start_connection_actor()\n\n  handler.func(fn(msg, state) {\n    let assert Ok(_) = tcp.send(state.socket, bit_builder.from_bit_string(msg))\n    actor.Continue(state)\n  })\n  |&gt; acceptor.new_pool\n  |&gt; acceptor.with_init(fn(sender) {\n    process.send(connections, Connected(sender))\n\n    Nil\n  })\n  |&gt; acceptor.with_close(fn(sender) {\n    process.send(connections, Disconnected(sender))\n\n    Nil\n  })\n  |&gt; glisten.serve(8080, _)\n  |&gt; result.map(fn(_) { process.sleep_forever() })\n}\n```\n\nBut you can also drop down to the lower level listen/accept flow if you&#39;d prefer\nto manage connections yourself, or only handle a small number at a time.\n\n```gleam\nimport gleam/io\nimport gleam/result\nimport glisten/socket/options.{ActiveMode, Passive}\nimport glisten/tcp\n\npub fn main() {\n  use listener &lt;- result.then(tcp.listen(8000, [ActiveMode(Passive)]))\n  use socket &lt;- result.then(tcp.accept(listener))\n  use msg &lt;- result.then(tcp.receive(socket, 0))\n  io.debug(#(&quot;got a msg&quot;, msg))\n\n  Ok(Nil)\n}\n```\n\nSee [mist](https://github.com/rawhat/mist) for HTTP support built on top of\nthis library.\n","url":"index.html"},{"doc":"glisten/logger","title":"error","content":"pub fn error(data: a) -&gt; Nil\n\nSynonyms:\nglisten/logger.error\nglisten/logger error","url":"glisten/logger.html#error"},{"doc":"glisten/logger","title":"glisten/logger","content":"","url":"glisten/logger.html"},{"doc":"glisten/socket","title":"ListenSocket","content":"pub opaque type ListenSocket\n\n\nSynonyms:\nglisten/socket.ListenSocket\nglisten/socket ListenSocket","url":"glisten/socket.html#ListenSocket"},{"doc":"glisten/socket","title":"Socket","content":"pub opaque type Socket\n\n\nSynonyms:\nglisten/socket.Socket\nglisten/socket Socket","url":"glisten/socket.html#Socket"},{"doc":"glisten/socket","title":"SocketReason","content":"pub type SocketReason {\n  Closed\n  Timeout\n  Badarg\n  Terminated\n  Eaddrinuse\n  Eaddrnotavail\n  Eafnosupport\n  Ealready\n  Econnaborted\n  Econnrefused\n  Econnreset\n  Edestaddrreq\n  Ehostdown\n  Ehostunreach\n  Einprogress\n  Eisconn\n  Emsgsize\n  Enetdown\n  Enetunreach\n  Enopkg\n  Enoprotoopt\n  Enotconn\n  Enotty\n  Enotsock\n  Eproto\n  Eprotonosupport\n  Eprototype\n  Esocktnosupport\n  Etimedout\n  Ewouldblock\n  Exbadport\n  Exbadseq\n  Eacces\n  Eagain\n  Ebadf\n  Ebadmsg\n  Ebusy\n  Edeadlk\n  Edeadlock\n  Edquot\n  Eexist\n  Efault\n  Efbig\n  Eftype\n  Eintr\n  Einval\n  Eio\n  Eisdir\n  Eloop\n  Emfile\n  Emlink\n  Emultihop\n  Enametoolong\n  Enfile\n  Enobufs\n  Enodev\n  Enolck\n  Enolink\n  Enoent\n  Enomem\n  Enospc\n  Enosr\n  Enostr\n  Enosys\n  Enotblk\n  Enotdir\n  Enotsup\n  Enxio\n  Eopnotsupp\n  Eoverflow\n  Eperm\n  Epipe\n  Erange\n  Erofs\n  Espipe\n  Esrch\n  Estale\n  Etxtbsy\n  Exdev\n}\n\nClosed\n\n\nTimeout\n\n\nBadarg\n\n\nTerminated\n\n\nEaddrinuse\n\n\nEaddrnotavail\n\n\nEafnosupport\n\n\nEalready\n\n\nEconnaborted\n\n\nEconnrefused\n\n\nEconnreset\n\n\nEdestaddrreq\n\n\nEhostdown\n\n\nEhostunreach\n\n\nEinprogress\n\n\nEisconn\n\n\nEmsgsize\n\n\nEnetdown\n\n\nEnetunreach\n\n\nEnopkg\n\n\nEnoprotoopt\n\n\nEnotconn\n\n\nEnotty\n\n\nEnotsock\n\n\nEproto\n\n\nEprotonosupport\n\n\nEprototype\n\n\nEsocktnosupport\n\n\nEtimedout\n\n\nEwouldblock\n\n\nExbadport\n\n\nExbadseq\n\n\nEacces\n\n\nEagain\n\n\nEbadf\n\n\nEbadmsg\n\n\nEbusy\n\n\nEdeadlk\n\n\nEdeadlock\n\n\nEdquot\n\n\nEexist\n\n\nEfault\n\n\nEfbig\n\n\nEftype\n\n\nEintr\n\n\nEinval\n\n\nEio\n\n\nEisdir\n\n\nEloop\n\n\nEmfile\n\n\nEmlink\n\n\nEmultihop\n\n\nEnametoolong\n\n\nEnfile\n\n\nEnobufs\n\n\nEnodev\n\n\nEnolck\n\n\nEnolink\n\n\nEnoent\n\n\nEnomem\n\n\nEnospc\n\n\nEnosr\n\n\nEnostr\n\n\nEnosys\n\n\nEnotblk\n\n\nEnotdir\n\n\nEnotsup\n\n\nEnxio\n\n\nEopnotsupp\n\n\nEoverflow\n\n\nEperm\n\n\nEpipe\n\n\nErange\n\n\nErofs\n\n\nEspipe\n\n\nEsrch\n\n\nEstale\n\n\nEtxtbsy\n\n\nExdev\n\n\nSynonyms:\nglisten/socket.SocketReason\nglisten/socket SocketReason","url":"glisten/socket.html#SocketReason"},{"doc":"glisten/socket","title":"glisten/socket","content":"","url":"glisten/socket.html"},{"doc":"glisten/socket/options","title":"ActiveState","content":"pub type ActiveState {\n  Once\n  Passive\n  Count(Int)\n  Active\n}\n Mapping to the {active, _} option\nOnce\n\n\nPassive\n\n\nCount(Int)\n\n\nActive\n\n\nSynonyms:\nglisten/socket/options.ActiveState\nglisten/socket/options ActiveState","url":"glisten/socket/options.html#ActiveState"},{"doc":"glisten/socket/options","title":"SocketMode","content":"pub type SocketMode {\n  Binary\n}\n Mode for the socket.  Currently `list` is not supported\nBinary\n\n\nSynonyms:\nglisten/socket/options.SocketMode\nglisten/socket/options SocketMode","url":"glisten/socket/options.html#SocketMode"},{"doc":"glisten/socket/options","title":"TcpOption","content":"pub type TcpOption {\n  Backlog(Int)\n  Nodelay(Bool)\n  Linger(#(Bool, Int))\n  SendTimeout(Int)\n  SendTimeoutClose(Bool)\n  Reuseaddr(Bool)\n  ActiveMode(ActiveState)\n  Mode(SocketMode)\n  Certfile(String)\n  Keyfile(String)\n  AlpnPreferredProtocols(List(String))\n}\n Options for the TCP socket\nBacklog(Int)\n\n\nNodelay(Bool)\n\n\nLinger(#(Bool, Int))\n\n\nSendTimeout(Int)\n\n\nSendTimeoutClose(Bool)\n\n\nReuseaddr(Bool)\n\n\nActiveMode(ActiveState)\n\n\nMode(SocketMode)\n\n\nCertfile(String)\n\n\nKeyfile(String)\n\n\nAlpnPreferredProtocols(List(String))\n\n\nSynonyms:\nglisten/socket/options.TcpOption\nglisten/socket/options TcpOption","url":"glisten/socket/options.html#TcpOption"},{"doc":"glisten/socket/options","title":"merge_with_defaults","content":"pub fn merge_with_defaults(options: List(TcpOption)) -&gt; List(\n  TcpOption,\n)\n\nSynonyms:\nglisten/socket/options.merge_with_defaults\nglisten/socket/options merge_with_defaults","url":"glisten/socket/options.html#merge_with_defaults"},{"doc":"glisten/socket/options","title":"to_map","content":"pub fn to_map(options: List(TcpOption)) -&gt; Map(Atom, Dynamic)\n\nSynonyms:\nglisten/socket/options.to_map\nglisten/socket/options to_map","url":"glisten/socket/options.html#to_map"},{"doc":"glisten/socket/options","title":"glisten/socket/options","content":"","url":"glisten/socket/options.html"},{"doc":"glisten/ssl","title":"accept","content":"pub fn accept(socket: ListenSocket) -&gt; Result(\n  Socket,\n  SocketReason,\n)\n\nSynonyms:\nglisten/ssl.accept\nglisten/ssl accept","url":"glisten/ssl.html#accept"},{"doc":"glisten/ssl","title":"accept_timeout","content":"pub fn accept_timeout(socket: ListenSocket, timeout: Int) -&gt; Result(\n  Socket,\n  SocketReason,\n)\n\nSynonyms:\nglisten/ssl.accept_timeout\nglisten/ssl accept_timeout","url":"glisten/ssl.html#accept_timeout"},{"doc":"glisten/ssl","title":"close","content":"pub fn close(socket: Socket) -&gt; Result(Nil, SocketReason)\n\nSynonyms:\nglisten/ssl.close\nglisten/ssl close","url":"glisten/ssl.html#close"},{"doc":"glisten/ssl","title":"controlling_process","content":"pub fn controlling_process(socket: Socket, pid: Pid) -&gt; Result(\n  Nil,\n  Atom,\n)\n\nSynonyms:\nglisten/ssl.controlling_process\nglisten/ssl controlling_process","url":"glisten/ssl.html#controlling_process"},{"doc":"glisten/ssl","title":"do_shutdown","content":"pub fn do_shutdown(socket: Socket, write: Atom) -&gt; Result(\n  Nil,\n  SocketReason,\n)\n\nSynonyms:\nglisten/ssl.do_shutdown\nglisten/ssl do_shutdown","url":"glisten/ssl.html#do_shutdown"},{"doc":"glisten/ssl","title":"handshake","content":"pub fn handshake(socket: Socket) -&gt; Result(Socket, Nil)\n\nSynonyms:\nglisten/ssl.handshake\nglisten/ssl handshake","url":"glisten/ssl.html#handshake"},{"doc":"glisten/ssl","title":"listen","content":"pub fn listen(port: Int, options: List(TcpOption)) -&gt; Result(\n  ListenSocket,\n  SocketReason,\n)\n Start listening over SSL on a port with the given options\nSynonyms:\nglisten/ssl.listen\nglisten/ssl listen","url":"glisten/ssl.html#listen"},{"doc":"glisten/ssl","title":"negotiated_protocol","content":"pub fn negotiated_protocol(socket: Socket) -&gt; Result(\n  String,\n  String,\n)\n\nSynonyms:\nglisten/ssl.negotiated_protocol\nglisten/ssl negotiated_protocol","url":"glisten/ssl.html#negotiated_protocol"},{"doc":"glisten/ssl","title":"receive","content":"pub fn receive(socket: Socket, length: Int) -&gt; Result(\n  BitString,\n  SocketReason,\n)\n\nSynonyms:\nglisten/ssl.receive\nglisten/ssl receive","url":"glisten/ssl.html#receive"},{"doc":"glisten/ssl","title":"receive_timeout","content":"pub fn receive_timeout(socket: Socket, length: Int, timeout: Int) -&gt; Result(\n  BitString,\n  SocketReason,\n)\n\nSynonyms:\nglisten/ssl.receive_timeout\nglisten/ssl receive_timeout","url":"glisten/ssl.html#receive_timeout"},{"doc":"glisten/ssl","title":"send","content":"pub fn send(socket: Socket, packet: BitBuilder) -&gt; Result(\n  Nil,\n  SocketReason,\n)\n\nSynonyms:\nglisten/ssl.send\nglisten/ssl send","url":"glisten/ssl.html#send"},{"doc":"glisten/ssl","title":"set_opts","content":"pub fn set_opts(socket: Socket, opts: List(TcpOption)) -&gt; Result(\n  Nil,\n  Nil,\n)\n Update the optons for a socket (mutates the socket)\nSynonyms:\nglisten/ssl.set_opts\nglisten/ssl set_opts","url":"glisten/ssl.html#set_opts"},{"doc":"glisten/ssl","title":"shutdown","content":"pub fn shutdown(socket: Socket) -&gt; Result(Nil, SocketReason)\n\nSynonyms:\nglisten/ssl.shutdown\nglisten/ssl shutdown","url":"glisten/ssl.html#shutdown"},{"doc":"glisten/ssl","title":"glisten/ssl","content":"","url":"glisten/ssl.html"},{"doc":"glisten/tcp","title":"accept","content":"pub fn accept(socket: ListenSocket) -&gt; Result(\n  Socket,\n  SocketReason,\n)\n\nSynonyms:\nglisten/tcp.accept\nglisten/tcp accept","url":"glisten/tcp.html#accept"},{"doc":"glisten/tcp","title":"accept_timeout","content":"pub fn accept_timeout(socket: ListenSocket, timeout: Int) -&gt; Result(\n  Socket,\n  SocketReason,\n)\n\nSynonyms:\nglisten/tcp.accept_timeout\nglisten/tcp accept_timeout","url":"glisten/tcp.html#accept_timeout"},{"doc":"glisten/tcp","title":"close","content":"pub fn close(socket: a) -&gt; Result(Nil, SocketReason)\n\nSynonyms:\nglisten/tcp.close\nglisten/tcp close","url":"glisten/tcp.html#close"},{"doc":"glisten/tcp","title":"controlling_process","content":"pub fn controlling_process(socket: Socket, pid: Pid) -&gt; Result(\n  Nil,\n  Atom,\n)\n\nSynonyms:\nglisten/tcp.controlling_process\nglisten/tcp controlling_process","url":"glisten/tcp.html#controlling_process"},{"doc":"glisten/tcp","title":"do_shutdown","content":"pub fn do_shutdown(socket: Socket, write: Atom) -&gt; Result(\n  Nil,\n  SocketReason,\n)\n\nSynonyms:\nglisten/tcp.do_shutdown\nglisten/tcp do_shutdown","url":"glisten/tcp.html#do_shutdown"},{"doc":"glisten/tcp","title":"handshake","content":"pub fn handshake(socket: Socket) -&gt; Result(Socket, Nil)\n\nSynonyms:\nglisten/tcp.handshake\nglisten/tcp handshake","url":"glisten/tcp.html#handshake"},{"doc":"glisten/tcp","title":"listen","content":"pub fn listen(port: Int, options: List(TcpOption)) -&gt; Result(\n  ListenSocket,\n  SocketReason,\n)\n Start listening over TCP on a port with the given options\nSynonyms:\nglisten/tcp.listen\nglisten/tcp listen","url":"glisten/tcp.html#listen"},{"doc":"glisten/tcp","title":"negotiated_protocol","content":"pub fn negotiated_protocol(socket: Socket) -&gt; a\n\nSynonyms:\nglisten/tcp.negotiated_protocol\nglisten/tcp negotiated_protocol","url":"glisten/tcp.html#negotiated_protocol"},{"doc":"glisten/tcp","title":"receive","content":"pub fn receive(socket: Socket, length: Int) -&gt; Result(\n  BitString,\n  SocketReason,\n)\n\nSynonyms:\nglisten/tcp.receive\nglisten/tcp receive","url":"glisten/tcp.html#receive"},{"doc":"glisten/tcp","title":"receive_timeout","content":"pub fn receive_timeout(socket: Socket, length: Int, timeout: Int) -&gt; Result(\n  BitString,\n  SocketReason,\n)\n\nSynonyms:\nglisten/tcp.receive_timeout\nglisten/tcp receive_timeout","url":"glisten/tcp.html#receive_timeout"},{"doc":"glisten/tcp","title":"send","content":"pub fn send(socket: Socket, packet: BitBuilder) -&gt; Result(\n  Nil,\n  SocketReason,\n)\n\nSynonyms:\nglisten/tcp.send\nglisten/tcp send","url":"glisten/tcp.html#send"},{"doc":"glisten/tcp","title":"set_opts","content":"pub fn set_opts(socket: Socket, opts: List(TcpOption)) -&gt; Result(\n  Nil,\n  Nil,\n)\n Update the optons for a socket (mutates the socket)\nSynonyms:\nglisten/tcp.set_opts\nglisten/tcp set_opts","url":"glisten/tcp.html#set_opts"},{"doc":"glisten/tcp","title":"shutdown","content":"pub fn shutdown(socket: Socket) -&gt; Result(Nil, SocketReason)\n\nSynonyms:\nglisten/tcp.shutdown\nglisten/tcp shutdown","url":"glisten/tcp.html#shutdown"},{"doc":"glisten/tcp","title":"socket_info","content":"pub fn socket_info(socket: Socket) -&gt; Map(a, b)\n\nSynonyms:\nglisten/tcp.socket_info\nglisten/tcp socket_info","url":"glisten/tcp.html#socket_info"},{"doc":"glisten/tcp","title":"glisten/tcp","content":"","url":"glisten/tcp.html"},{"doc":"glisten/socket/transport","title":"Transport","content":"pub type Transport {\n  Ssl(\n    accept: Accept,\n    accept_timeout: AcceptTimeout,\n    close: Close,\n    controlling_process: ControllingProcess,\n    handshake: Handshake,\n    listen: Listen,\n    negotiated_protocol: NegotiatedProtocol,\n    receive: Receive,\n    receive_timeout: ReceiveTimeout,\n    send: Send,\n    set_opts: SetOpts,\n    shutdown: Shutdown,\n    socket_info: SocketInfo,\n  )\n  Tcp(\n    accept: Accept,\n    accept_timeout: AcceptTimeout,\n    close: Close,\n    controlling_process: ControllingProcess,\n    handshake: Handshake,\n    listen: Listen,\n    negotiated_protocol: NegotiatedProtocol,\n    receive: Receive,\n    receive_timeout: ReceiveTimeout,\n    send: Send,\n    set_opts: SetOpts,\n    shutdown: Shutdown,\n    socket_info: SocketInfo,\n  )\n}\n\nSsl(\n  accept: Accept,\n  accept_timeout: AcceptTimeout,\n  close: Close,\n  controlling_process: ControllingProcess,\n  handshake: Handshake,\n  listen: Listen,\n  negotiated_protocol: NegotiatedProtocol,\n  receive: Receive,\n  receive_timeout: ReceiveTimeout,\n  send: Send,\n  set_opts: SetOpts,\n  shutdown: Shutdown,\n  socket_info: SocketInfo,\n)\n\n\nTcp(\n  accept: Accept,\n  accept_timeout: AcceptTimeout,\n  close: Close,\n  controlling_process: ControllingProcess,\n  handshake: Handshake,\n  listen: Listen,\n  negotiated_protocol: NegotiatedProtocol,\n  receive: Receive,\n  receive_timeout: ReceiveTimeout,\n  send: Send,\n  set_opts: SetOpts,\n  shutdown: Shutdown,\n  socket_info: SocketInfo,\n)\n\n\nSynonyms:\nglisten/socket/transport.Transport\nglisten/socket/transport Transport","url":"glisten/socket/transport.html#Transport"},{"doc":"glisten/socket/transport","title":"socket_info","content":"pub fn socket_info(socket: Socket) -&gt; Map(a, b)\n\nSynonyms:\nglisten/socket/transport.socket_info\nglisten/socket/transport socket_info","url":"glisten/socket/transport.html#socket_info"},{"doc":"glisten/socket/transport","title":"ssl","content":"pub fn ssl() -&gt; Transport\n\nSynonyms:\nglisten/socket/transport.ssl\nglisten/socket/transport ssl","url":"glisten/socket/transport.html#ssl"},{"doc":"glisten/socket/transport","title":"tcp","content":"pub fn tcp() -&gt; Transport\n\nSynonyms:\nglisten/socket/transport.tcp\nglisten/socket/transport tcp","url":"glisten/socket/transport.html#tcp"},{"doc":"glisten/socket/transport","title":"glisten/socket/transport","content":"","url":"glisten/socket/transport.html"},{"doc":"glisten/handler","title":"ClientIp","content":"pub type ClientIp =\n  Result(#(#(Int, Int, Int, Int), Int), Nil)\n\n\nSynonyms:\nglisten/handler.ClientIp\nglisten/handler ClientIp","url":"glisten/handler.html#ClientIp"},{"doc":"glisten/handler","title":"Handler","content":"pub type Handler(data) {\n  Handler(\n    socket: Socket,\n    initial_data: data,\n    loop: LoopFn(data),\n    on_init: Option(fn(Subject(HandlerMessage)) -&gt; Nil),\n    on_close: Option(fn(Subject(HandlerMessage)) -&gt; Nil),\n    transport: Transport,\n  )\n}\n\nHandler(\n  socket: Socket,\n  initial_data: data,\n  loop: LoopFn(data),\n  on_init: Option(fn(Subject(HandlerMessage)) -&gt; Nil),\n  on_close: Option(fn(Subject(HandlerMessage)) -&gt; Nil),\n  transport: Transport,\n)\n\n\nSynonyms:\nglisten/handler.Handler\nglisten/handler Handler","url":"glisten/handler.html#Handler"},{"doc":"glisten/handler","title":"HandlerFunc","content":"pub type HandlerFunc(data) =\n  fn(BitString, LoopState(data)) -&gt; actor.Next(LoopState(data))\n\n\nSynonyms:\nglisten/handler.HandlerFunc\nglisten/handler HandlerFunc","url":"glisten/handler.html#HandlerFunc"},{"doc":"glisten/handler","title":"HandlerMessage","content":"pub type HandlerMessage {\n  Close\n  Ready\n  ReceiveMessage(BitString)\n  SendMessage(BitBuilder)\n  Ssl(socket: Port, data: BitString)\n  SslClosed\n  Tcp(socket: Port, data: BitString)\n  TcpClosed\n}\n All message types that the handler will receive, or that you can\n send to the handler process\nClose\n\n\nReady\n\n\nReceiveMessage(BitString)\n\n\nSendMessage(BitBuilder)\n\n\nSsl(socket: Port, data: BitString)\n\n\nSslClosed\n\n\nTcp(socket: Port, data: BitString)\n\n\nTcpClosed\n\n\nSynonyms:\nglisten/handler.HandlerMessage\nglisten/handler HandlerMessage","url":"glisten/handler.html#HandlerMessage"},{"doc":"glisten/handler","title":"LoopFn","content":"pub type LoopFn(data) =\n  fn(HandlerMessage, LoopState(data)) -&gt;\n    actor.Next(LoopState(data))\n\n\nSynonyms:\nglisten/handler.LoopFn\nglisten/handler LoopFn","url":"glisten/handler.html#LoopFn"},{"doc":"glisten/handler","title":"LoopState","content":"pub type LoopState(data) {\n  LoopState(\n    client_ip: ClientIp,\n    socket: Socket,\n    sender: Subject(HandlerMessage),\n    transport: Transport,\n    data: data,\n  )\n}\n\nLoopState(\n  client_ip: ClientIp,\n  socket: Socket,\n  sender: Subject(HandlerMessage),\n  transport: Transport,\n  data: data,\n)\n\n\nSynonyms:\nglisten/handler.LoopState\nglisten/handler LoopState","url":"glisten/handler.html#LoopState"},{"doc":"glisten/handler","title":"func","content":"pub fn func(handler func: fn(BitString, LoopState(a)) -&gt;\n    Next(LoopState(a))) -&gt; fn(HandlerMessage, LoopState(a)) -&gt;\n  Next(LoopState(a))\n This helper will generate a TCP handler that will call your handler function\n with the BitString data in the packet as well as the LoopState, with any\n associated state data you are maintaining\nSynonyms:\nglisten/handler.func\nglisten/handler func","url":"glisten/handler.html#func"},{"doc":"glisten/handler","title":"start","content":"pub fn start(handler: Handler(a)) -&gt; Result(\n  Subject(HandlerMessage),\n  StartError,\n)\n Starts an actor for the TCP connection\nSynonyms:\nglisten/handler.start\nglisten/handler start","url":"glisten/handler.html#start"},{"doc":"glisten/handler","title":"glisten/handler","content":"","url":"glisten/handler.html"},{"doc":"glisten/acceptor","title":"AcceptorError","content":"pub type AcceptorError {\n  AcceptError\n  HandlerError\n  ControlError\n}\n\nAcceptError\n\n\nHandlerError\n\n\nControlError\n\n\nSynonyms:\nglisten/acceptor.AcceptorError\nglisten/acceptor AcceptorError","url":"glisten/acceptor.html#AcceptorError"},{"doc":"glisten/acceptor","title":"AcceptorMessage","content":"pub type AcceptorMessage {\n  AcceptConnection(ListenSocket)\n}\n\nAcceptConnection(ListenSocket)\n\n\nSynonyms:\nglisten/acceptor.AcceptorMessage\nglisten/acceptor AcceptorMessage","url":"glisten/acceptor.html#AcceptorMessage"},{"doc":"glisten/acceptor","title":"AcceptorState","content":"pub type AcceptorState {\n  AcceptorState(\n    sender: Subject(AcceptorMessage),\n    socket: Option(Socket),\n    transport: Transport,\n  )\n}\n\nAcceptorState(\n  sender: Subject(AcceptorMessage),\n  socket: Option(Socket),\n  transport: Transport,\n)\n\n\nSynonyms:\nglisten/acceptor.AcceptorState\nglisten/acceptor AcceptorState","url":"glisten/acceptor.html#AcceptorState"},{"doc":"glisten/acceptor","title":"Pool","content":"pub type Pool(data) {\n  Pool(\n    listener_socket: ListenSocket,\n    handler: LoopFn(data),\n    initial_data: data,\n    pool_count: Int,\n    on_init: Option(fn(Subject(HandlerMessage)) -&gt; Nil),\n    on_close: Option(fn(Subject(HandlerMessage)) -&gt; Nil),\n    transport: Transport,\n  )\n}\n\nPool(\n  listener_socket: ListenSocket,\n  handler: LoopFn(data),\n  initial_data: data,\n  pool_count: Int,\n  on_init: Option(fn(Subject(HandlerMessage)) -&gt; Nil),\n  on_close: Option(fn(Subject(HandlerMessage)) -&gt; Nil),\n  transport: Transport,\n)\n\n\nSynonyms:\nglisten/acceptor.Pool\nglisten/acceptor Pool","url":"glisten/acceptor.html#Pool"},{"doc":"glisten/acceptor","title":"new_pool","content":"pub fn new_pool(handler: fn(HandlerMessage, LoopState(Nil)) -&gt;\n    Next(LoopState(Nil))) -&gt; fn(ListenSocket) -&gt; Pool(Nil)\n Initialize acceptor pool where each handler has no state\nSynonyms:\nglisten/acceptor.new_pool\nglisten/acceptor new_pool","url":"glisten/acceptor.html#new_pool"},{"doc":"glisten/acceptor","title":"new_pool_with_data","content":"pub fn new_pool_with_data(handler: fn(\n    HandlerMessage,\n    LoopState(a),\n  ) -&gt; Next(LoopState(a)), initial_data: a) -&gt; fn(ListenSocket) -&gt;\n  Pool(a)\n Initialize an acceptor pool where each handler holds some state\nSynonyms:\nglisten/acceptor.new_pool_with_data\nglisten/acceptor new_pool_with_data","url":"glisten/acceptor.html#new_pool_with_data"},{"doc":"glisten/acceptor","title":"over_ssl","content":"pub fn over_ssl(make_pool: fn(ListenSocket) -&gt; Pool(a)) -&gt; fn(\n  ListenSocket,\n) -&gt; Pool(a)\n Use SSL for the underlying socket.\nSynonyms:\nglisten/acceptor.over_ssl\nglisten/acceptor over_ssl","url":"glisten/acceptor.html#over_ssl"},{"doc":"glisten/acceptor","title":"start","content":"pub fn start(pool: Pool(a)) -&gt; Result(\n  Subject(AcceptorMessage),\n  StartError,\n)\n Worker process that handles `accept`ing connections and starts a new process\n which receives the messages from the socket\nSynonyms:\nglisten/acceptor.start\nglisten/acceptor start","url":"glisten/acceptor.html#start"},{"doc":"glisten/acceptor","title":"start_pool","content":"pub fn start_pool(pool: Pool(a)) -&gt; Result(\n  Subject(Message),\n  StartError,\n)\n Starts a pool of acceptors of size `pool_count`.\n\n Runs `loop_fn` on ever message received\nSynonyms:\nglisten/acceptor.start_pool\nglisten/acceptor start_pool","url":"glisten/acceptor.html#start_pool"},{"doc":"glisten/acceptor","title":"with_close","content":"pub fn with_close(make_pool: fn(ListenSocket) -&gt; Pool(a), func: fn(\n    Subject(HandlerMessage),\n  ) -&gt; Nil) -&gt; fn(ListenSocket) -&gt; Pool(a)\n Add an `on_close` handler to the acceptor pool\nSynonyms:\nglisten/acceptor.with_close\nglisten/acceptor with_close","url":"glisten/acceptor.html#with_close"},{"doc":"glisten/acceptor","title":"with_init","content":"pub fn with_init(make_pool: fn(ListenSocket) -&gt; Pool(a), func: fn(\n    Subject(HandlerMessage),\n  ) -&gt; Nil) -&gt; fn(ListenSocket) -&gt; Pool(a)\n Add an `on_init` handler to the acceptor pool\nSynonyms:\nglisten/acceptor.with_init\nglisten/acceptor with_init","url":"glisten/acceptor.html#with_init"},{"doc":"glisten/acceptor","title":"with_pool_size","content":"pub fn with_pool_size(make_pool: fn(ListenSocket) -&gt; Pool(a), pool_count: Int) -&gt; fn(\n  ListenSocket,\n) -&gt; Pool(a)\n Adjust the number of TCP acceptors in the pool\nSynonyms:\nglisten/acceptor.with_pool_size\nglisten/acceptor with_pool_size","url":"glisten/acceptor.html#with_pool_size"},{"doc":"glisten/acceptor","title":"glisten/acceptor","content":"","url":"glisten/acceptor.html"},{"doc":"glisten","title":"StartError","content":"pub type StartError {\n  ListenerClosed\n  ListenerTimeout\n  AcceptorTimeout\n  AcceptorFailed(process.ExitReason)\n  AcceptorCrashed(Dynamic)\n  SystemError(SocketReason)\n}\n Reasons that `serve` might fail\nListenerClosed\n\n\nListenerTimeout\n\n\nAcceptorTimeout\n\n\nAcceptorFailed(process.ExitReason)\n\n\nAcceptorCrashed(Dynamic)\n\n\nSystemError(SocketReason)\n\n\nSynonyms:\nglisten.StartError\nglisten StartError","url":"glisten.html#StartError"},{"doc":"glisten","title":"serve","content":"pub fn serve(port: Int, with_pool: fn(ListenSocket) -&gt; Pool(a)) -&gt; Result(\n  Nil,\n  StartError,\n)\n Sets up a TCP listener with the given acceptor pool. The second argument\n can be obtained from the `glisten/acceptor.{acceptor_pool}` function.\nSynonyms:\nglisten.serve\nglisten serve","url":"glisten.html#serve"},{"doc":"glisten","title":"serve_ssl","content":"pub fn serve_ssl(port port: Int, certfile certfile: String, keyfile keyfile: String, with_pool with_pool: fn(\n    ListenSocket,\n  ) -&gt; Pool(a)) -&gt; Result(Nil, StartError)\n Sets up a SSL listener with the given acceptor pool. The second argument\n can be obtained from the `glisten/acceptor.{acceptor_pool}` function.\nSynonyms:\nglisten.serve_ssl\nglisten serve_ssl","url":"glisten.html#serve_ssl"},{"doc":"glisten","title":"glisten","content":"","url":"glisten.html"}]);